﻿using Infragistics.Controls.Grids;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;
using System.Windows.Interactivity;

namespace XamGrid_sample.Behaviors
{
    public class XamGridSelectedItemsBehavior : Behavior<XamGrid>
    {
        #region BehaviorSelectedItems Dependency property

        public ObservableCollection<object> BehaviorSelectedItems
        {
            get { return (ObservableCollection<object>)GetValue(BehaviorSelectedItemsProperty); }
            set
            {
                SetValue(BehaviorSelectedItemsProperty, value);
            }
        }

        public static DependencyProperty BehaviorSelectedItemsProperty =
            DependencyProperty.Register("BehaviorSelectedItems", typeof(ObservableCollection<object>), typeof(XamGridSelectedItemsBehavior), new UIPropertyMetadata(null));

        #endregion // BehaviorSelectedItems 

        protected override void OnAttached()
        {
            base.OnAttached();

            this.AssociatedObject.Loaded += AssociatedObject_Loaded;
        }

        private void AssociatedObject_Loaded(object sender, RoutedEventArgs e)
        {
            this.AssociatedObject.SelectedRowsCollectionChanged += AssociatedObject_SelectedRowsCollectionChanged;            
        }
        
        private void AssociatedObject_SelectedRowsCollectionChanged(object sender, SelectionCollectionChangedEventArgs<SelectedRowsCollection> e)
        {
            BehaviorSelectedItems.Clear();
            foreach (Row selectedRow in this.AssociatedObject.SelectionSettings.SelectedRows)
            {
                BehaviorSelectedItems.Add(selectedRow.Data);
            }
        }

        protected override void OnDetaching()
        {
            base.OnDetaching();

            this.AssociatedObject.SelectedRowsCollectionChanged -= AssociatedObject_SelectedRowsCollectionChanged;
            this.AssociatedObject.Loaded -= AssociatedObject_Loaded;
        }        
    }
}
